@@ -14,7 +14,7 @@ import pyisbn
 import re
 import itertools
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 __all__ = [
     'FatRecord',
@@ -32,12 +32,10 @@ __all__ = [
 def pairwise(iterable):
     """
     http://docs.python.org/2/library/itertools.html#recipes
-    s -> (s0,s1), (s1,s2), (s2, s3), ...
+    s -> (s0, s1), (s1, s2), (s2, s3), ...
     """
-    a, b = itertools.tee(iterable)
-    next(b, None)
-    return itertools.izip(a, b)
-
+    a = iter(iterable)
+    return itertools.izip(a, a)
 
 def _equals(value):
     """ equality """
@@ -185,72 +183,6 @@ class FatRecord(Record):
     def __init__(self, *args, **kwargs):
         super(FatRecord, self).__init__(*args, **kwargs)
 
-    @classmethod
-    def from_doc(cls, doc, **kwargs):
-        """ Create a FatRecord from a dictionary as it is
-        stored in Elasticsearch.
-
-        Elasticsearch JSON > dict > FatRecord
-
-        Keyword arguments used:
-
-        * encoding      [utf-8]
-        * to_unicode    [True]
-        * force_utf8    [True]
-
-        Example doc:
-
-        {
-            "content": {
-                "830":[
-                    {
-                        "w":"(DE-576)027236307",
-                        "g":"15",
-                        "v":"15",
-                        "a":"Hauterive-Champréveyres",
-                        "ind2":"0",
-                        "ind1":" "
-                    },
-                    {
-                        "w":"(DE-576)017312833",
-                        "v":"40",
-                        "a":"Archéologie neuchâteloise",
-                        "ind2":"0",
-                        "ind1":" "
-                    }
-                ],
-                "300":[
-                    {
-                        "b":"Ill., graph. Darst., Kt.",
-                        "a":"163, 39 S. :",
-                        "ind2":" ",
-                        "ind1":" "
-                    }
-                ],
-                "260": ...
-            ...
-            "original":"00919cam a2200253  b4500001001000..."
-            "sha1":"bd8d3f250d2c8cb210dbb6323240b897f48ddcac",
-            "content_type":"application/marc",
-            "meta": {
-                "tags":[
-                    "da88ecbc0c348fc1f232a41d435c04bd974f390b"
-                ],
-                "timestamp":"201302071200",
-                ...
-            }
-        }
-        """
-        assert(isinstance(doc, dict))
-        encoding = kwargs.get('encoding', 'utf-8')
-        to_unicode = kwargs.get('to_unicode', True)
-        force_utf8 = kwargs.get('force_utf8', True)
-        if not 'original' in doc:
-            raise ValueError('document without `original` key')
-        original = doc.get('original', '').encode(encoding)
-        return FatRecord(data=original, to_unicode=to_unicode,
-                         force_utf8=force_utf8)
-
     def add(self, tag, data=None, indicators=None, **kwargs):
         """ Add a field to a record. Example:
 
@@ -287,7 +219,10 @@ class FatRecord(Record):
 
     def remove(self, fieldspec):
         """
-        Removes **all** fields with tag `tag`.
+        Removes fields or subfields according to `fieldspec`.
+
+        If a non-control field subfield removal leaves no other subfields,
+        delete the field entirely.
         """
 
         pattern = r'(?P<field>[^.]+)(.(?P<subfield>[^.]+))?'
@@ -309,6 +244,7 @@ class FatRecord(Record):
                 else:
                     field.subfields = updated
             else:
+                # it is a control field
                 self.remove_field(field)
 
     def firstvalue(self, *fieldspecs, **kwargs):
@@ -452,6 +388,72 @@ class FincMarc(FatRecord):
         self.source_id = None
         self.record_id = None
 
+    @classmethod
+    def from_doc(cls, doc, **kwargs):
+        """ Create a FatRecord from a dictionary as it is
+        stored in Elasticsearch.
+
+        Elasticsearch JSON > dict > FatRecord
+
+        Keyword arguments used:
+
+        * encoding      [utf-8]
+        * to_unicode    [True]
+        * force_utf8    [True]
+
+        Example doc:
+
+        {
+            "content": {
+                "830":[
+                    {
+                        "w":"(DE-576)027236307",
+                        "g":"15",
+                        "v":"15",
+                        "a":"Hauterive-Champréveyres",
+                        "ind2":"0",
+                        "ind1":" "
+                    },
+                    {
+                        "w":"(DE-576)017312833",
+                        "v":"40",
+                        "a":"Archéologie neuchâteloise",
+                        "ind2":"0",
+                        "ind1":" "
+                    }
+                ],
+                "300":[
+                    {
+                        "b":"Ill., graph. Darst., Kt.",
+                        "a":"163, 39 S. :",
+                        "ind2":" ",
+                        "ind1":" "
+                    }
+                ],
+                "260": ...
+            ...
+            "original":"00919cam a2200253  b4500001001000..."
+            "sha1":"bd8d3f250d2c8cb210dbb6323240b897f48ddcac",
+            "content_type":"application/marc",
+            "meta": {
+                "tags":[
+                    "da88ecbc0c348fc1f232a41d435c04bd974f390b"
+                ],
+                "timestamp":"201302071200",
+                ...
+            }
+        }
+        """
+        assert(isinstance(doc, dict))
+        encoding = kwargs.get('encoding', 'utf-8')
+        to_unicode = kwargs.get('to_unicode', True)
+        force_utf8 = kwargs.get('force_utf8', True)
+        if not 'original' in doc:
+            raise ValueError('document without `original` key')
+        original = doc.get('original', '').encode(encoding)
+        return FatRecord(data=original, to_unicode=to_unicode,
+                         force_utf8=force_utf8)
+
     def get_control_number(self):
         """ Return the control number value.
         Raises `AttributeError` on missing value.
